@@ -1,7 +1,7 @@
 package TableData::Object::Base;
 
-our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010;
 use strict;
@@ -189,6 +189,12 @@ sub uniq_col_names { die "Must be implemented by subclass" }
 
 sub const_col_names { die "Must be implemented by subclass" }
 
+sub del_col { die "Must be implemented by subclass" }
+
+sub rename_col { die "Must be implemented by subclass" }
+
+sub switch_cols { die "Must be implemented by subclass" }
+
 1;
 # ABSTRACT: Base class for TableData::Object::*
 
@@ -204,7 +210,7 @@ TableData::Object::Base - Base class for TableData::Object::*
 
 =head1 VERSION
 
-This document describes version 0.08 of TableData::Object::Base (from Perl distribution TableData-Object), released on 2016-01-11.
+This document describes version 0.09 of TableData::Object::Base (from Perl distribution TableData-Object), released on 2016-01-13.
 
 =head1 METHODS
 
@@ -328,6 +334,37 @@ Example:
 In the above example, C<a> does not exist in the second hash, <b> has two
 different values.
 
+=head2 $td->del_col($name_or_idx) => str
+
+Delete a single column. Will die if the underlying form does not support column
+deletion (e.g. aos and hash).
+
+Will modify data. Will also adjust column positions. And will also modify spec,
+if spec was given.
+
+Return the deleted column name.
+
+If column is unknown, will simply return undef.
+
+=head2 $td->rename_col($old_name_or_idx, $new_name)
+
+Rename a column to a new name. Will die if the underlying form does not support
+column rename (e.g. aos and hash).
+
+Die if column is unknown. Die if new column name is a number, or an existing
+column name. Will simply return if new column name is the same as old name.
+
+Might modify data (e.g. in aohos). Will modify spec, if spec was given.
+
+=head2 $td->switch_cols($name_or_idx1, $name_or_idx2)
+
+Switch two columns. Will die if the underlying form does not support column
+rename (e.g. aos and hash).
+
+Die if either column is unknown. Will simply return if both are the same column.
+
+Might modify data (e.g. in aohos). Will modify spec, if spec was given.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableData-Object>.
