@@ -1,7 +1,7 @@
 package TableData::Object::aos;
 
-our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,6 +66,18 @@ sub const_col_names {
     ('elem');
 }
 
+sub del_col {
+    die "Cannot delete column in aos table";
+}
+
+sub rename_col {
+    die "Cannot rename column in aos table";
+}
+
+sub switch_cols {
+    die "Cannot switch column in aos table";
+}
+
 1;
 # ABSTRACT: Manipulate array of scalars via table object
 
@@ -81,7 +93,7 @@ TableData::Object::aos - Manipulate array of scalars via table object
 
 =head1 VERSION
 
-This document describes version 0.08 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2016-01-11.
+This document describes version 0.09 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -97,11 +109,6 @@ or:
 
  my $td = TableData::Object::aos->new([1,2,3]);
 
-To manipulate:
-
- $td->cols_by_name; # {elem=>0}
- $td->cols_by_idx;  # ['elem']
-
 =head1 DESCRIPTION
 
 This class lets you manipulate an array of scalars as a table object. The table
