@@ -1,7 +1,7 @@
 package TableData::Object::hash;
 
-our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -73,6 +73,10 @@ sub const_col_names {
     ('value');
 }
 
+sub switch_cols {
+    die "Cannot switch column in aos table";
+}
+
 1;
 # ABSTRACT: Manipulate hash via table object
 
@@ -88,7 +92,7 @@ TableData::Object::hash - Manipulate hash via table object
 
 =head1 VERSION
 
-This document describes version 0.08 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2016-01-11.
+This document describes version 0.09 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -104,11 +108,6 @@ or:
 
  my $td = TableData::Object::hash->new({foo=>10, bar=>20, baz=>30});
 
-To manipulate:
-
- $td->cols_by_name; # {key=>0, value=>1}
- $td->cols_by_idx;  # ['key', 'value']
-
 =head1 DESCRIPTION
 
 This class lets you manipulate a hash as a table object. The table will have two
